@@ -16,7 +16,7 @@
 import os
 import cl_base
 import cl_utils
-import md5
+import hashlib
 
 class fillVars(object, cl_base.glob_attr):
 
@@ -26,9 +26,8 @@ class fillVars(object, cl_base.glob_attr):
         password - пароль
         encrypt - алгоритм шифрования, например '{SSHA}'
         """
-        runStr='%s slappasswd -s %s -h %s'%\
-                (self.path_env, password, encrypt)
-        res=self._runos(runStr)
+        runStr='slappasswd -s %s -h %s' %(password, encrypt)
+        res = self._runos(runStr)
         if res:
             return res.strip()
         print "Error generate hash (slappasswd)"
@@ -230,7 +229,7 @@ class fillVars(object, cl_base.glob_attr):
         replServers = replServers.split(",")
         for replServer in replServers:
             if replServer:
-                md5hex = md5.new(replServer).hexdigest()
+                md5hex = hashlib.md5(replServer).hexdigest()
                 dStart = 0
                 dEnd = 3
                 dMax = 32
@@ -552,3 +551,45 @@ class fillVars(object, cl_base.glob_attr):
         if userJid:
             return userJid.partition('@')[0]
         return ""
+
+    def get_ld_dns_dn(self):
+        """DN сервиса DNS"""
+        return "ou=%s,%s" %(self.Get('ld_dns_login'),
+            self.Get('ld_services_dn'))
+
+    def get_ld_dns_pw(self):
+        """пароль администратора сервиса DNS"""
+        return cl_utils.genpassword().strip()
+
+    def get_ld_dns_hash(self):
+        """hash пароля администратора сервиса DNS"""
+        return self.getHash(self.Get('ld_dns_pw'), self.Get('ld_encrypt'))
+
+    def get_sr_dns_net_allow(self):
+        """Доступные сети для сервиса DNS"""
+        netAllow = self.Get("os_net_allow")
+        if netAllow:
+            return netAllow
+        return ""
+
+    def get_sr_dns_net_allow_pass(self):
+        """Текст в named.conf - доступные сети"""
+        def getNetAllow(netAllow):
+            netAllow = netAllow.split(",")
+            foundLoc = False
+            for net in netAllow:
+                if net[:4] == '127.':
+                    foundLoc = True
+                    break
+            if not foundLoc:
+                netAllow.append("127.0.0.1")
+            netAllow = map(lambda x: "%s;"%x,netAllow)
+            netAllow = " ".join(netAllow)
+            return "listen-on { %s };"%netAllow
+        netAllow = self.Get("sr_dns_net_allow")
+        if netAllow:
+            return getNetAllow(netAllow)
+        netAllow = self.Get("os_net_allow")
+        if netAllow:
+            return getNetAllow(netAllow)
+        return "listen-on { 127.0.0.1; };"
\ No newline at end of file
